aboutsummaryrefslogtreecommitdiff
path: root/contrib/ntp/ntpq/ntpq-opts.c
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/ntp/ntpq/ntpq-opts.c')
-rw-r--r--contrib/ntp/ntpq/ntpq-opts.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/contrib/ntp/ntpq/ntpq-opts.c b/contrib/ntp/ntpq/ntpq-opts.c
index e6398fd724b4..3e176c057652 100644
--- a/contrib/ntp/ntpq/ntpq-opts.c
+++ b/contrib/ntp/ntpq/ntpq-opts.c
@@ -1,7 +1,7 @@
/*
* EDIT THIS FILE WITH CAUTION (ntpq-opts.c)
*
- * It has been AutoGen-ed May 31, 2023 at 02:49:56 PM by AutoGen 5.18.16
+ * It has been AutoGen-ed June 6, 2023 at 04:38:03 AM by AutoGen 5.18.16
* From the definitions ntpq-opts.def
* and the template file options
*
@@ -74,7 +74,7 @@ extern FILE * option_usage_fp;
* static const strings for ntpq options
*/
static char const ntpq_opt_strs[2068] =
-/* 0 */ "ntpq 4.2.8p16\n"
+/* 0 */ "ntpq 4.2.8p17\n"
"Copyright (C) 1992-2023 The University of Delaware and Network Time Foundation, all rights reserved.\n"
"This is free software. It is licensed for use, modification and\n"
"redistribution under the terms of the NTP License, copies of which\n"
@@ -140,13 +140,13 @@ static char const ntpq_opt_strs[2068] =
/* 1858 */ "no-load-opts\0"
/* 1871 */ "no\0"
/* 1874 */ "NTPQ\0"
/* 1879 */ "ntpq - standard NTP query program - Ver. 4.2.8p16\n"
"Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n\0"
/* 1999 */ "$HOME\0"
/* 2005 */ ".\0"
/* 2007 */ ".ntprc\0"
/* 2014 */ "https://bugs.ntp.org, bugs@ntp.org\0"
-/* 2049 */ "ntpq 4.2.8p16\0"
+/* 2049 */ "ntpq 4.2.8p17\0"
/* 2063 */ "hash";
/**
@@ -873,7 +873,7 @@ static void bogus_function(void) {
translate option names.
*/
/* referenced via ntpqOptions.pzCopyright */
- puts(_("ntpq 4.2.8p16\n\
+ puts(_("ntpq 4.2.8p17\n\
Copyright (C) 1992-2023 The University of Delaware and Network Time Foundation, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the NTP License, copies of which\n\
@@ -945,11 +945,11 @@ implied warranty.\n"));
puts(_("load options from a config file"));
/* referenced via ntpqOptions.pzUsageTitle */
- puts(_("ntpq - standard NTP query program - Ver. 4.2.8p16\n\
+ puts(_("ntpq - standard NTP query program - Ver. 4.2.8p17\n\
Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n"));
/* referenced via ntpqOptions.pzFullVersion */
- puts(_("ntpq 4.2.8p16"));
+ puts(_("ntpq 4.2.8p17"));
/* referenced via ntpqOptions.pzFullUsage */
puts(_("<<<NOT-FOUND>>>"));
@@ -140,13 +140,13 @@ static char const ntpq_opt_strs[2068] =
/* 1871 */ "no\0"
/* 1874 */ "NTPQ\0"
-/* 1879 */ "ntpq - standard NTP query program - Ver. 4.2.8p16\n"
+/* 1879 */ "ntpq - standard NTP query program - Ver. 4.2.8p17\n"
"Usage: %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]... [ host ...]\n\0"
/* 1999 */ "$HOME\0"